"""manual_0002_add_personal_chores

Revision ID: manual_0002
Revises: manual_0001
Create Date: 2025-05-22 08:00:00.000000

"""
from typing import Sequence, Union

from alembic import op
import sqlalchemy as sa
from sqlalchemy.dialects import postgresql

# revision identifiers, used by Alembic.
revision: str = 'manual_0002'
down_revision: Union[str, None] = 'manual_0001'
branch_labels: Union[str, Sequence[str], None] = None
depends_on: Union[str, Sequence[str], None] = None

# Enum definition for ChoreTypeEnum
chore_type_enum = postgresql.ENUM('personal', 'group', name='choretypeenum', create_type=False)

def upgrade() -> None:
    """Upgrade schema."""
    # Create choretypeenum type if it doesn't exist
    connection = op.get_bind()
    if not connection.dialect.has_type(connection, 'choretypeenum'):
        chore_type_enum.create(connection)

    # Add type column and make group_id nullable
    op.add_column('chores', sa.Column('type', chore_type_enum, nullable=True))
    op.alter_column('chores', 'group_id',
        existing_type=sa.Integer(),
        nullable=True,
        existing_server_default=None
    )

    # Set default type for existing chores
    op.execute("UPDATE chores SET type = 'group' WHERE type IS NULL")

    # Make type column non-nullable after setting defaults
    op.alter_column('chores', 'type',
        existing_type=chore_type_enum,
        nullable=False,
        existing_server_default=None
    )

def downgrade() -> None:
    """Downgrade schema."""
    # Make group_id non-nullable again
    op.alter_column('chores', 'group_id',
        existing_type=sa.Integer(),
        nullable=False,
        existing_server_default=None
    )

    # Remove type column
    op.drop_column('chores', 'type')

    # Don't drop the enum type as it might be used by other tables 